# pycounts_tat

Author: Tiffany Timbers

[![ci-cd](https://github.com/ttimbers/pycounts_tat/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/ttimbers/pycounts_tat/actions/workflows/ci-cd.yml)

Calculate word counts in a text file!

## Installation

```bash
$ pip install pycounts_tat
```

## Usage

To import the package and check the version:

```
import pycounts_tat

print(pycounts_tat.__version__)
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pycounts_tat` was created by Monty Python. It is licensed under the terms of the MIT license.

## Credits

`pycounts_tat` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
